@@ -112,17 +112,18 @@ case $os in
 esac
 
 # bash will eat your spaces, so let's array. see http://mywiki.wooledge.org/BashFAQ/050 for more fun.
-params=("--user" "puppet" "--group" "puppet" "--chdir" "$dir" "--realname" "puppetserver" "--operating-system" "$os" "--name" "puppetserver" "--package-version" "8.6.0" "--release" "1" "--platform-version" "8")
+params=("--user" "puppet" "--group" "puppet" "--chdir" "$dir" "--realname" "puppetserver" "--operating-system" "$os" "--name" "puppetserver" "--package-version" "8.6.3" "--release" "1" "--platform-version" "8")
 if [ -n "$os_version" ]; then params+=("--os-version" "$os_version"); fi
 if [ -n "$os_dist" ]; then params+=("--dist" "$os_dist"); fi
 
-params+=('--description' "$(printf "Puppet Labs puppetserver\nContains: Puppet Server (puppetlabs/puppetserver 8.6.0,org.clojure/clojure 1.11.2,org.bouncycastle/bcpkix-jdk18on 1.74,puppetlabs/jruby-utils 5.1.0,puppetlabs/puppetserver 8.6.0,com.puppetlabs/trapperkeeper-webserver-jetty10 1.0.18,puppetlabs/trapperkeeper-metrics 2.0.3)")")
+params+=('--description' "$(printf "Puppet Labs puppetserver\nContains: Puppet Server (puppetlabs/puppetserver 8.6.3,org.clojure/clojure 1.11.2,org.bouncycastle/bcpkix-jdk18on 1.78.1,puppetlabs/jruby-utils 5.2.0,puppetlabs/puppetserver 8.6.3,com.puppetlabs/trapperkeeper-webserver-jetty10 1.0.18,puppetlabs/trapperkeeper-metrics 2.0.4)")")
 
 
 
 
 
 params+=('--create-dir' '/opt/puppetlabs/server/data/puppetserver/jars')
+params+=('--create-dir' '/opt/puppetlabs/server/data/puppetserver/yaml')
 
 
 
