@@ -143,8 +143,8 @@ function task_install_docs_deb {
 # install docs for rpm based systems
 function task_install_docs_rpm {
   if [ -d ext/docs ]; then
-    install -d "${DESTDIR}${app_prefix}/share/doc/puppetserver-8.6.0"
-    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetserver-8.6.0"
+    install -d "${DESTDIR}${app_prefix}/share/doc/puppetserver-8.6.3"
+    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetserver-8.6.3"
   fi
 }
 
@@ -164,8 +164,8 @@ function task_install {
 
         install -m 0644 ext/system-config/services.d/bootstrap.cfg "${DESTDIR}${system_config_dir}/services.d/bootstrap.cfg"
     
-    install -m 0644 ext/config/conf.d/puppetserver.conf "${DESTDIR}${projconfdir}/conf.d/puppetserver.conf"
     install -m 0644 ext/config/request-logging.xml "${DESTDIR}${projconfdir}/request-logging.xml"
+    install -m 0644 ext/config/conf.d/puppetserver.conf "${DESTDIR}${projconfdir}/conf.d/puppetserver.conf"
     install -m 0644 ext/config/logback.xml "${DESTDIR}${projconfdir}/logback.xml"
     install -m 0644 ext/config/services.d/ca.cfg "${DESTDIR}${projconfdir}/services.d/ca.cfg"
     install -m 0644 ext/config/conf.d/global.conf "${DESTDIR}${projconfdir}/conf.d/global.conf"
@@ -186,15 +186,15 @@ function task_install {
     ln -s "../apps/${real_name}/bin/${real_name}" "${DESTDIR}${symbindir}/${real_name}"
     install -d -m 0755 "${DESTDIR}${uxbindir}"
     ln -s "../server/apps/${real_name}/bin/${real_name}" "${DESTDIR}${uxbindir}/${real_name}"
-    install -m 0755 ext/cli/irb "${dest_apps_dir}/cli/apps/irb"
-    install -m 0755 ext/cli/start "${dest_apps_dir}/cli/apps/start"
-    install -m 0755 ext/cli/gem "${dest_apps_dir}/cli/apps/gem"
-    install -m 0755 ext/cli/ruby "${dest_apps_dir}/cli/apps/ruby"
-    install -m 0755 ext/cli/reload "${dest_apps_dir}/cli/apps/reload"
     install -m 0755 ext/cli/foreground "${dest_apps_dir}/cli/apps/foreground"
-    install -m 0755 ext/cli/stop "${dest_apps_dir}/cli/apps/stop"
-    install -m 0755 ext/cli/ca "${dest_apps_dir}/cli/apps/ca"
     install -m 0755 ext/cli/dropsonde "${dest_apps_dir}/cli/apps/dropsonde"
+    install -m 0755 ext/cli/ca "${dest_apps_dir}/cli/apps/ca"
+    install -m 0755 ext/cli/irb "${dest_apps_dir}/cli/apps/irb"
+    install -m 0755 ext/cli/gem "${dest_apps_dir}/cli/apps/gem"
+    install -m 0755 ext/cli/reload "${dest_apps_dir}/cli/apps/reload"
+    install -m 0755 ext/cli/ruby "${dest_apps_dir}/cli/apps/ruby"
+    install -m 0755 ext/cli/stop "${dest_apps_dir}/cli/apps/stop"
+    install -m 0755 ext/cli/start "${dest_apps_dir}/cli/apps/start"
 
 if [ -e "ext/cli_defaults/cli-defaults.sh" ]; then
     install -m 0755 ext/cli_defaults/cli-defaults.sh "${dest_apps_dir}/cli/"
@@ -203,6 +203,7 @@ fi
     install -d -m 0755 "${DESTDIR}${rundir}"
     install -d -m 700 "${DESTDIR}${app_logdir}"
     install -d -m 700 "${DESTDIR}/opt/puppetlabs/server/data/puppetserver/jars"
+    install -d -m 700 "${DESTDIR}/opt/puppetlabs/server/data/puppetserver/yaml"
 }
 
 function task_install_redhat {
@@ -359,6 +360,8 @@ function task_postinst_permissions {
     chmod 0755 $rundir
     chown puppet:puppet /opt/puppetlabs/server/data/puppetserver/jars
     chmod 700 /opt/puppetlabs/server/data/puppetserver/jars
+    chown puppet:puppet /opt/puppetlabs/server/data/puppetserver/yaml
+    chmod 700 /opt/puppetlabs/server/data/puppetserver/yaml
 }
 
 # Install logrotate (usually el7, fedora 16 and above)
