@@ -1,4 +1,4 @@
-(def ps-version "8.6.0")
+(def ps-version "8.6.3")
 
 (defn deploy-info
   [url]
@@ -30,7 +30,7 @@
 
   :min-lein-version "2.9.1"
 
-  :parent-project {:coords [puppetlabs/clj-parent "7.3.14"]
+  :parent-project {:coords [puppetlabs/clj-parent "7.3.35"]
                    :inherit [:managed-dependencies]}
 
   :dependencies [[org.clojure/clojure]
@@ -47,7 +47,6 @@
                  [liberator]
                  [org.apache.commons/commons-exec]
                  [io.dropwizard.metrics/metrics-core]
-                 [org.yaml/snakeyaml "2.0"]
 
                  ;; We do not currently use this dependency directly, but
                  ;; we have documentation that shows how users can use it to
@@ -100,7 +99,8 @@
                        :puppet-platform-version 8
                        :java-args ~(str "-Xms2g -Xmx2g "
                                      "-Djruby.logger.class=com.puppetlabs.jruby_utils.jruby.Slf4jLogger")
-                       :create-dirs ["/opt/puppetlabs/server/data/puppetserver/jars"]
+                       :create-dirs ["/opt/puppetlabs/server/data/puppetserver/jars"
+                                     "/opt/puppetlabs/server/data/puppetserver/yaml"]
                        :repo-target "puppet8"
                        :nonfinal-repo-target "puppet8-nightly"
                        :bootstrap-source :services-d
